@@ -3,9 +3,9 @@
 ## author: Thomas Alexander Gerds
 ## created: May 31 2016 (11:32)
 ## Version:
-## last-updated: Nov  4 2019 (12:22) 
+## last-updated: Jan 27 2020 (07:36) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 57
+##     Update #: 60
 #----------------------------------------------------------------------
 ##
 ### Commentary:
@@ -89,7 +89,6 @@ print.scoreAUC <- function(x,B,digits=3,response.type,percent=TRUE,...){
         if (match("lower",colnames(X$score),nomatch=0)) X$score[,lower:=sprintf(fmt=fmt,100*lower)]
         if (match("upper",colnames(X$score),nomatch=0)) X$score[,upper:=sprintf(fmt=fmt,100*upper)]
         print(X$score,digits=digits,...)
-        message("\nNOTE: Values are multiplied by 100 and given in % (use print(...,percent=FALSE) to avoid this.")
         if (length(x$contrasts)>0){
             X$contrasts[,delta.AUC:=sprintf(fmt=fmt,100*delta.AUC)]
             if (match("se",colnames(X$contrasts),nomatch=0)) X$contrasts[,se:=NULL]
@@ -111,7 +110,7 @@ print.scoreAUC <- function(x,B,digits=3,response.type,percent=TRUE,...){
 #' @method print scoreBrier
 #' @export
 print.scoreBrier <- function(x,B,digits=3,response.type,percent=TRUE,...){
-    Brier=IPA=se=lower=upper=delta.Brier=NULL
+    Brier=IPA=se.conservative=se=lower=upper=delta.Brier=NULL
     cat("\nResults by model:\n\n")
     if (percent[1]==TRUE){
         fmt <- paste0("%1.",digits[[1]],"f")
@@ -119,10 +118,10 @@ print.scoreBrier <- function(x,B,digits=3,response.type,percent=TRUE,...){
         X$score[,Brier:=sprintf(fmt=fmt,100*Brier)]
         if (match("IPA",colnames(X$score),nomatch=0)) X$score[,IPA:=sprintf(fmt=fmt,100*IPA)]
         if (match("se",colnames(X$score),nomatch=0)) X$score[,se:=NULL]
+        if (match("se.conservative",colnames(X$score),nomatch=0)) X$score[,se.conservative:=NULL]
         if (match("lower",colnames(X$score),nomatch=0)) X$score[,lower:=sprintf(fmt=fmt,100*lower)]
         if (match("upper",colnames(X$score),nomatch=0)) X$score[,upper:=sprintf(fmt=fmt,100*upper)]
         print(X$score,...)
-        message("\nNOTE: Values are multiplied by 100 and given in % (use print(...,percent=FALSE) to avoid this.")
         if (length(x$contrasts)>0){
             X$contrasts[,delta.Brier:=sprintf(fmt=fmt,100*delta.Brier)]
             if (match("se",colnames(X$contrasts),nomatch=0)) X$contrasts[,se:=NULL]
@@ -130,8 +129,8 @@ print.scoreBrier <- function(x,B,digits=3,response.type,percent=TRUE,...){
             if (match("upper",colnames(X$contrasts),nomatch=0)) X$contrasts[,upper:=sprintf(fmt=fmt,100*upper)]
             cat("\nResults of model comparisons:\n\n")
             print(X$contrasts,...)
-            message("\nNOTE: Values are multiplied by 100 and given in % (use print(...,percent=FALSE) to avoid this.")
         }
+        message("\nNOTE: Values are multiplied by 100 and given in % (use print(...,percent=FALSE) to avoid this.")
     }else{
         print(x$score,digits=digits,...)
         if (length(x$contrasts)>0){
