@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: maj 30 2018 (15:58) 
 ## Version: 
-## Last-Updated: Jan 29 2019 (10:49) 
-##           By: Thomas Alexander Gerds
-##     Update #: 173
+## Last-Updated: jul 30 2019 (15:19) 
+##           By: Brice Ozenne
+##     Update #: 178
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -50,9 +50,9 @@ transformSE <- function(estimate, se, type){
     }else if(type == "atanh"){
         ## fisher transform: f(x) = 1/2 log(1+x) - 1/2 log(1-x)
         ##                   df(x) = dx/(2+2x) + dx/(2-2x) = dx(1/(1+x)+1/(1-x))/2
-        ##                         = dx/(1+x^2)
-        ##               Var(f(x)) = Var(x)/(1+x^2)
-        newse <- se / (1+estimate^2)
+        ##                         = dx/(1-x^2)
+        ##               Var(f(x)) = Var(x)/(1-x^2)
+        newse <- se / (1-estimate^2)
     }
 
     index0 <- which(se==0)
@@ -96,9 +96,9 @@ transformIID <- function(estimate, iid, type){
     }else if(type == "atanh"){
         ## fisher transform: f(x) = 1/2 log(1+x) - 1/2 log(1-x)
         ##                   df(x) = dx/(2+2x) + dx/(2-2x) = dx(1/(1+x)+1/(1-x))/2
-        ##                         = dx/(1+x^2)
-        ##               Var(f(x)) = Var(x)/(1+x^2)
-        newiid <- sliceScale_cpp(iid, M = 1 + estimate^2 )
+        ##                         = dx/(1-x^2)
+        ##               Var(f(x)) = Var(x)/(1-x^2)
+        newiid <- sliceScale_cpp(iid, M = 1 - estimate^2 )
     }
     index0 <- which(iid==0)
     if(length(index0)>0){
@@ -207,7 +207,7 @@ transformP <- function(estimate, se, null, type){
 ##'
 ##' @param estimate [numeric matrix] the estimate value before transformation.
 ##' @param se [numeric matrix] the standard error before transformation.
-##' @param iid [numeric array] the standard error before transformation.
+##' @param iid [numeric array] the iid decomposition before transformation.
 ##' @param null [numeric] the value of the estimate (before transformation) under the null hypothesis.
 ##' @param type [character] the transforamtion.
 ##' Can be \code{"log"}, \code{"loglog"}, \code{"cloglog"}, or \code{"atanh"} (Fisher transform).
@@ -232,6 +232,7 @@ transformCIBP <- function(estimate, se, iid, null,
                           ci, band, p.value){
 
     out <- list()
+
     ## ** transformation
     if(type != "none"){
         ## standard error
