@@ -3,9 +3,9 @@
 ## author: Thomas Alexander Gerds
 ## created: Jan  4 2016 (14:30) 
 ## Version: 
-## last-updated: Jan 28 2019 (16:54) 
+## last-updated: Nov  3 2019 (19:29) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 123
+##     Update #: 139
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -31,10 +31,9 @@ test_that("R squared/IPA", {
     r1 <- rsquared(f1,newdata=d)
     r2 <- IPA(f2,newdata=d)
     full <- Score(list(f1=f1,f2=f2),formula=Y~1,data=d,conf.int=TRUE,summary=c("RR"),plots="ROC")
-    expect_equal(r1$IPA.gain[1],full$Brier$score[model=="f1",IPA])
+    expect_equal(r1$IPA.drop[1],full$Brier$score[model=="f1",IPA])
     expect_equal(r2$IPA[2],full$Brier$score[model=="f2",IPA])
 })
-
 # }}}
 # {{{ "vcov AUC"
 if (class(try(riskRegression.test,silent=TRUE))[1]!="try-error"){
@@ -194,8 +193,8 @@ test_that("survival outcome,Brier Score, external prediction",{
     expect_equal(b$Brier$score[,Brier],as.vector(unlist(a$AppErr)))
 })
 
-# }}}
-# {{{integrated Brier score
+                                        # }}}
+                                        # {{{integrated Brier score
 test_that("integrated Brier score",{
     set.seed(18)
     trainSurv <- sampleData(100,outcome="survival")
@@ -216,16 +215,20 @@ test_that("integrated Brier score",{
     ## cbind(a1,b1)
     expect_equal(as.numeric(c(a1,use.names=FALSE)),c(b1))
 })
-# }}}
-# {{{ "survival outcome uncensored"
+                                        # }}}
+
+                                        # {{{ "survival outcome uncensored"
 test_that("survival outcome uncensored",{
     library(survival)
+    library(data.table)
     library(randomForestSRC)
     library(riskRegression)
+    library(prodlim)
+    set.seed(8)
     d <- sampleData(100,outcome="survival")
     d$event=1
-    cx=coxph(Surv(time,event)~.,d,x=TRUE)
-    rfx=rfsrc(Surv(time,event)~.,d,ntree=10)
+    cx=coxph(Surv(time,event)~X1+X2+X3+X4+X5+X6+X7+X8+X9+X10,d,x=TRUE)
+    rfx=rfsrc(Surv(time,event)~X1+X2+X3+X4+X5+X6+X7+X8+X9+X10,data=d,ntree=10)
     out <- Score(list(Cox=cx,RF=rfx),
                  data=d,
                  metrics="brier",
@@ -236,8 +239,9 @@ test_that("survival outcome uncensored",{
                  se.fit=FALSE)
     out
 })
-# }}}
-# {{{ "binary outcome: Brier"
+                                        # }}}
+
+                                        # {{{ "binary outcome: Brier"
 test_that("binary outcome: Brier",{
     set.seed(47)
     D <- sampleData(n=47,outcome="binary")
@@ -258,8 +262,8 @@ test_that("binary outcome: Brier",{
     expect_equal(S1$Brier$score$Brier,S3$Brier$score$Brier)
     expect_equal(S2$Brier$score$Brier,S3$Brier$score$Brier)
 })
-# }}}
-# {{{ "binary outcome: AUC"
+                                        # }}}
+                                        # {{{ "binary outcome: AUC"
 test_that("binary outcome: AUC", {   
     set.seed(17)
     y <- rbinom(100, 1, .5)
@@ -294,8 +298,8 @@ test_that("binary outcome: AUC", {
     ## expect_equal(daim.diff$"CI(upper)",-score.diff$lower)
     ## expect_equal(daim.diff$"P.Value",score.diff$p)
 })
-# }}}
-# {{{ "Leave one out bootstrap: Number of models and time points"
+                                        # }}}
+                                        # {{{ "Leave one out bootstrap: Number of models and time points"
 if (class(try(riskRegression.test,silent=TRUE))[1]!="try-error"){
     test_that("Number of models and time points", {
         library(pec)
@@ -323,7 +327,7 @@ if (class(try(riskRegression.test,silent=TRUE))[1]!="try-error"){
         expect_equal(r1$Brier$score[model=="a"],r2$Brier$score[model=="a" & times==1000])
         ## expect_equal(r1$AUC$score[model=="a"],r2$AUC$score[model=="a" & times==1000])
     })
-    # {{{ "Bootstrap cross validation
+                                        # {{{ "Bootstrap cross validation
     test_that("Number of models and time points", {
         library(pec)
         data(GBSG2)
@@ -350,8 +354,8 @@ if (class(try(riskRegression.test,silent=TRUE))[1]!="try-error"){
         expect_equal(r1$Brier$score[model=="a"],r2$Brier$score[model=="a" & times==1000])
         ## expect_equal(r1$AUC$score[model=="a"],r2$AUC$score[model=="a" & times==1000])
     })
-    # }}}
-    # {{{ "LOOB: Number of models and time points"
+                                        # }}}
+                                        # {{{ "LOOB: Number of models and time points"
     test_that("LOOB: Number of models and time points", {   
         library(testthat)
         library(survival)
@@ -402,7 +406,7 @@ if (class(try(riskRegression.test,silent=TRUE))[1]!="try-error"){
                      A$Brier$score[model=="fit1"&times==365.25*4])
     })
 }
-# }}}
-# }}}
-#----------------------------------------------------------------------
+                                        # }}}
+                                        # }}}
+                                        #----------------------------------------------------------------------
 ### test-Score.R ends here
